# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class QueryDesks(BaseModel):
    desks: Optional["QueryDesksDesks"]


class QueryDesksDesks(BaseModel):
    results: Optional[list["QueryDesksDesksResults"]]


class QueryDesksDesksResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryDesksDesksResultsOwner"
    state: EntityState
    description: Optional[str]
    objectives: Optional[str]
    instructions: Optional[str]
    bureau: Optional["QueryDesksDesksResultsBureau"]
    agent_count: Optional[int] = Field(alias="agentCount")


class QueryDesksDesksResultsOwner(BaseModel):
    id: str


class QueryDesksDesksResultsBureau(BaseModel):
    id: str


QueryDesks.model_rebuild()
QueryDesksDesks.model_rebuild()
QueryDesksDesksResults.model_rebuild()
