# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteDesk(BaseModel):
    delete_desk: Optional["DeleteDeskDeleteDesk"] = Field(alias="deleteDesk")


class DeleteDeskDeleteDesk(BaseModel):
    id: str
    state: EntityState


DeleteDesk.model_rebuild()
