# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteDesks(BaseModel):
    delete_desks: Optional[list[Optional["DeleteDesksDeleteDesks"]]] = Field(
        alias="deleteDesks"
    )


class DeleteDesksDeleteDesks(BaseModel):
    id: str
    state: EntityState


DeleteDesks.model_rebuild()
