# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class AddAgentsToDesk(BaseModel):
    add_agents_to_desk: Optional["AddAgentsToDeskAddAgentsToDesk"] = Field(
        alias="addAgentsToDesk"
    )


class AddAgentsToDeskAddAgentsToDesk(BaseModel):
    id: str
    name: str
    state: EntityState
    description: Optional[str]
    objectives: Optional[str]
    instructions: Optional[str]
    bureau: Optional["AddAgentsToDeskAddAgentsToDeskBureau"]
    agents: Optional[list[Optional["AddAgentsToDeskAddAgentsToDeskAgents"]]]
    agent_count: Optional[int] = Field(alias="agentCount")


class AddAgentsToDeskAddAgentsToDeskBureau(BaseModel):
    id: str


class AddAgentsToDeskAddAgentsToDeskAgents(BaseModel):
    id: str
    name: str


AddAgentsToDesk.model_rebuild()
AddAgentsToDeskAddAgentsToDesk.model_rebuild()
