# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class AddDesksToBureau(BaseModel):
    add_desks_to_bureau: Optional["AddDesksToBureauAddDesksToBureau"] = Field(
        alias="addDesksToBureau"
    )


class AddDesksToBureauAddDesksToBureau(BaseModel):
    id: str
    name: str
    state: EntityState
    description: Optional[str]
    mission: Optional[str]
    directives: Optional[str]
    desks: Optional[list[Optional["AddDesksToBureauAddDesksToBureauDesks"]]]
    desk_count: Optional[int] = Field(alias="deskCount")


class AddDesksToBureauAddDesksToBureauDesks(BaseModel):
    id: str
    name: str


AddDesksToBureau.model_rebuild()
AddDesksToBureauAddDesksToBureau.model_rebuild()
