# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class RemoveDesksFromBureau(BaseModel):
    remove_desks_from_bureau: Optional["RemoveDesksFromBureauRemoveDesksFromBureau"] = (
        Field(alias="removeDesksFromBureau")
    )


class RemoveDesksFromBureauRemoveDesksFromBureau(BaseModel):
    id: str
    name: str
    state: EntityState
    description: Optional[str]
    mission: Optional[str]
    directives: Optional[str]
    desks: Optional[list[Optional["RemoveDesksFromBureauRemoveDesksFromBureauDesks"]]]
    desk_count: Optional[int] = Field(alias="deskCount")


class RemoveDesksFromBureauRemoveDesksFromBureauDesks(BaseModel):
    id: str
    name: str


RemoveDesksFromBureau.model_rebuild()
RemoveDesksFromBureauRemoveDesksFromBureau.model_rebuild()
